@@ -1,6 +1,5 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from email.mime.text import MIMEText
 from email.mime.base import MIMEBase
 from email.mime.multipart import MIMEMultipart
@@ -9,6 +8,7 @@ import logging
 from trytond.model import ModelSQL, ModelView, fields
 from trytond.tools import get_smtp_server
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class Event(ModelSQL, ModelView):
@@ -104,7 +104,7 @@ class Event(ModelSQL, ModelView):
         return ical
 
     def subject_body(self, type, event, owner):
-        lang_obj = self.pool.get('ir.lang')
+        lang_obj = Pool().get('ir.lang')
 
         if not (event and owner):
             return "", ""
@@ -228,7 +228,7 @@ class Event(ModelSQL, ModelView):
         :param event_id: the id of the calendar.event
         :return: list of email addresses sent
         '''
-        user_obj = self.pool.get('res.user')
+        user_obj = Pool().get('res.user')
 
         if not to_addrs:
             return to_addrs
@@ -283,7 +283,7 @@ class Event(ModelSQL, ModelView):
         return to_notify, owner
 
     def create(self, values):
-        attendee_obj = self.pool.get('calendar.event.attendee')
+        attendee_obj = Pool().get('calendar.event.attendee')
         res = super(Event, self).create(values)
 
         if Transaction().user == 0:
@@ -319,7 +319,7 @@ class Event(ModelSQL, ModelView):
         return res
 
     def write(self, ids, values):
-        attendee_obj = self.pool.get('calendar.event.attendee')
+        attendee_obj = Pool().get('calendar.event.attendee')
 
         if Transaction().user == 0:
             # user is 0 means write is triggered by another one
@@ -571,8 +571,8 @@ class EventAttendee(ModelSQL, ModelView):
                 })
 
     def subject_body(self, status, event, owner):
-        lang_obj = self.pool.get('ir.lang')
-        event_obj = self.pool.get('calendar.event')
+        lang_obj = Pool().get('ir.lang')
+        event_obj = Pool().get('calendar.event')
 
         if not (event and owner):
             return "", ""
@@ -699,7 +699,7 @@ class EventAttendee(ModelSQL, ModelView):
 
         return msg
 
-    def send_msg(self, from_addr, to_addr, msg, event_id):
+    def send_msg(self, from_addr, to_addr, msg, event):
         '''
         Send message
 
@@ -737,7 +737,7 @@ class EventAttendee(ModelSQL, ModelView):
         return organizer
 
     def write(self, ids, values):
-        event_obj = self.pool.get('calendar.event')
+        event_obj = Pool().get('calendar.event')
 
         if Transaction().user == 0:
             # user is 0 means write is triggered by another one
@@ -759,7 +759,7 @@ class EventAttendee(ModelSQL, ModelView):
         attendees = self.browse(ids)
         for attendee in attendees:
             owner = attendee.event.calendar.owner
-            if not owner or not owner.calendar_email_notification_partstat:
+            if not owner.calendar_email_notification_partstat:
                 continue
             organizer = self.organiser_to_notify(attendee)
             if not organizer:
@@ -789,7 +789,7 @@ class EventAttendee(ModelSQL, ModelView):
         return res
 
     def delete(self, ids):
-        event_obj = self.pool.get('calendar.event')
+        event_obj = Pool().get('calendar.event')
 
         if Transaction().user == 0:
             # user is 0 means the deletion is triggered by another one
@@ -804,7 +804,7 @@ class EventAttendee(ModelSQL, ModelView):
 
             if attendee.status == 'declined':
                 continue
-            if not owner or not owner.calendar_email_notification_partstat:
+            if not owner.calendar_email_notification_partstat:
                 continue
             organizer = self.organiser_to_notify(attendee)
             if not organizer:
@@ -833,7 +833,7 @@ class EventAttendee(ModelSQL, ModelView):
         return res
 
     def create(self, values):
-        event_obj = self.pool.get('calendar.event')
+        event_obj = Pool().get('calendar.event')
 
         res_id = super(EventAttendee, self).create(values)
         if Transaction().user == 0:
@@ -846,7 +846,7 @@ class EventAttendee(ModelSQL, ModelView):
 
         if (not attendee.status) or attendee.status in ('', 'needs-action'):
             return res_id
-        if not owner or not owner.calendar_email_notification_partstat:
+        if not owner.calendar_email_notification_partstat:
             return res_id
         organizer = self.organiser_to_notify(attendee)
         if not organizer:
